##  Using Tags to Filter Fact Sheets
Tags can be used to filter fact sheets in inventory, reports, and diagrams. They simplify the process of searching and filtering. Users can apply multiple tags to narrow down specific subsets of fact sheets, allowing for quicker access to the information they need.
By using tags, you can conduct more precise analyses. For example, you can tag applications with attributes like ‘High Risk’ or ‘Critical’ and then generate reports to assess the impact and risk levels across your organization.
You can apply tags as filters from the filter bar at the top or from the filter panel on the left. Simply type and search for the tag in the filter bar or find the tag group in the filter panel. To learn more, see [Searching and Applying Filters](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c8bfc7a441014bb2cc509aac188d0__searching_and_applying_filters) and [Applying Filters From the Filter Panel](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c8bfc7a441014bb2cc509aac188d0__applying_filters_from_the_filter_panel).
![Using Tags To Filter Fact Sheets](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275124b37a441014aa9db8e8c7b58a63_LowRes.png)
Using Tags To Filter Fact Sheets
If the tag group you are looking for is not visible in the filter panel, you can add it to the panel through the manager filter settings. To learn how, see [Displaying and Hiding Filters](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c8bfc7a441014bb2cc509aac188d0__displaying_and_hiding_filters).
You can combine tags while filtering with AND, OR, and NONE logic to refine your search. To learn more, see [Combining Filters with AND, OR, and IS NOT Logic](https://help.sap.com/docs/leanix/ea/advanced-filter-options?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758657c7a441014904ede2a21796386__combining_filters_with_and_or_and_is_not_logic).
